@@ -1,17 +1,23 @@
 import os
 import numpy as np
 import pickle
-from tensorflow.python.keras.models import Sequential
-from tensorflow.python.keras.models import load_model
-from tensorflow.python.keras.layers import Dense, Input
-from tensorflow.python.keras.layers import LSTM, GRU
-from tensorflow.python.keras.layers import Dropout, BatchNormalization, Activation, TimeDistributed, Masking
+from tensorflow.keras.models import Sequential
+from tensorflow.keras.models import load_model
+from tensorflow.keras.layers import Dense, Input
+from tensorflow.keras.layers import LSTM, GRU
+from tensorflow.keras.layers import Dropout, BatchNormalization, Activation, TimeDistributed, Masking
+from tensorflow.keras.models import Sequential, Model
 from tensorflow.python.keras.layers.convolutional import Conv1D, Conv2D
 from tensorflow.python.keras.layers.convolutional import MaxPooling1D, MaxPooling2D
 import matplotlib.pyplot as plt
 
+from tcn import TCN, tcn_full_summary
+import tensorflow_probability as tfp
 
-def train_model(X_train, X_test, y_train, y_test, sample_weights=None, fig_dir='.', retrain=True, epochs=25, plot_loss=True):
+
+
+def train_model(X_train, X_test, y_train, y_test, sample_weights=None, fig_dir='.', retrain=True, epochs=25,
+                plot_loss=True, dropout_rate=0.0, batch_size=100, nunits=100):
     """ Train Neural Network classifier and save model. """
 
     model_filename = os.path.join(fig_dir, "keras_model.hdf5")
@@ -23,32 +29,30 @@ def train_model(X_train, X_test, y_train, y_test, sample_weights=None, fig_dir='
     # X_test = np.dstack((X_test, colour))
     print("training...")
     if not retrain and os.path.isfile(model_filename):
-        model = load_model(model_filename)
+        model = load_model(model_filename, custom_objects={'TCN': TCN})
     else:
         num_classes = y_test.shape[-1]
 
-        model = Sequential()
+        # model = Sequential()
+        # model.add(Masking(mask_value=0.))
+        # model.add(LSTM(nunits, return_sequences=True, dropout=dropout_rate))
+        # # model.add(Dropout(0.2, seed=42))
+        # # model.add(BatchNormalization())
+        # model.add(LSTM(nunits, return_sequences=True, dropout=dropout_rate))
+        # # model.add(Dropout(0.2, seed=42))
+        # # model.add(BatchNormalization())
+        # # model.add(Dropout(0.2, seed=42))
+        # model.add(TimeDistributed(Dense(num_classes, activation='softmax')))
 
-        model.add(Masking(mask_value=0.))
+        inputs = Input(shape=(X_train.shape[1], X_train.shape[2]))
+        hidden = Masking(mask_value=0.)(inputs)
+        hidden = TCN(nunits, return_sequences=True, kernel_size=2, nb_stacks=1, dilations=[1, 2, 4, 8], padding='causal', use_skip_connections=True, dropout_rate=dropout_rate, activation='sigmoid')(hidden)
+        outputs = TimeDistributed(Dense(num_classes, activation='softmax'))(hidden)
+        model = Model(inputs, outputs)
 
-        # model.add(Conv1D(filters=32, kernel_size=3))
-        # model.add(BatchNormalization())
-        # model.add(Activation('relu'))
-        # model.add(MaxPooling1D(pool_size=1))
-        # model.add(Dropout(0.2, seed=42))
 
-        model.add(LSTM(100, return_sequences=True))
-        # model.add(Dropout(0.2, seed=42))
-        # model.add(BatchNormalization())
-
-        model.add(LSTM(100, return_sequences=True))
-        # model.add(Dropout(0.2, seed=42))
-        # model.add(BatchNormalization())
-        # model.add(Dropout(0.2, seed=42))
-
-        model.add(TimeDistributed(Dense(num_classes, activation='softmax')))
         model.compile(loss='categorical_crossentropy', optimizer='adam', metrics=['accuracy'])
-        history = model.fit(X_train, y_train, validation_data=(X_test, y_test), epochs=epochs, batch_size=500,
+        history = model.fit(X_train, y_train, validation_data=(X_test, y_test), epochs=epochs, batch_size=batch_size,
                             verbose=2, sample_weight=sample_weights)
 
         print(model.summary())
